svn commit: r1845462 - /tomcat/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 12:42:40 2018
New Revision: 1845462

URL: http://svn.apache.org/viewvc?rev=1845462&view=rev
Log:
Simplify script description.

Modified:
tomcat/trunk/res/scripts/check-mime.pl

Modified: tomcat/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/res/scripts/check-mime.pl?rev=1845462&r1=1845461&r2=1845462&view=diff
==
--- tomcat/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/trunk/res/scripts/check-mime.pl Thu Nov  1 12:42:40 2018
@@ -23,31 +23,31 @@
 # The script uses two mime type lists to describe
 # the merging between httpd and Tomcat mime types.
 #
-# 1) %TOMCAT_ONLY: Additional extensions for Tomcat that do not exist in httpd
-# 2) %TOMCAT_KEEP: Mime type differences for common extensions where we stick 
to
+# - %TOMCAT_ONLY: Additional extensions for Tomcat that do not exist in httpd
+# - %TOMCAT_KEEP: Mime type differences for common extensions where we stick to
 #the Tomcat definition
 
 # The script checks consistency between Tomcat and httpd according
-# to the lists 1) and 2) and generates a new web.xml:
+# to the lists TOMCAT_ONLY and TOMCAT_KEEP and generates a new web.xml:
 #
-# A) Additional extensions in Tomcat which are not part of 1)
+# A) Additional extensions in Tomcat which are not part of TOMCAT_ONLY
 #are logged. They will be removed in the generated new web.xml.
-#If you want to keep them, add them to the list 1) and run the
+#If you want to keep them, add them to TOMCAT_ONLY and run the
 #script again. If you want to remove them, commit the generated
 #new web.xml.
 # B) Mime type differences for the same extension between httpd
-#and Tomcat that are not part of the list 2) are logged.
+#and Tomcat that are not part of TOMCAT_KEEP are logged.
 #They will be overwritten wit the httpd definition in the generated
 #new web.xml. If you want to keep their Tomcat definition, add them
-#to the list 1) and run the script again. If you want to use the
+#to TOMCAT_KEEP and run the script again. If you want to use the
 #definitions from httpd, commit the generated new web.xml.
 # C) Additional extensions in httpd are logged. The script outputs a
 #merged web.xml, which already includes all those additional
-#extensions. If you want to keep them, update web.xml with the
-#generated new web.xml.
+#extensions. If you want to keep them, commit the generated
+#new web.xml.
 # D) If the extensions are not sorted alphabetically, a message is logged.
-#The generated web.xml will be always be sorted alphabetically.
-#If you want to fix the sort order, update web.xml with the generated
+#The generated web.xml will always be sorted alphabetically.
+#If you want to keep the alphabetical sort order, commit the generated
 #new web.xml.
 
 use strict;
@@ -412,4 +412,3 @@ for $extension (sort keys %httpd) {
 print $output_fh $tomcat_post;
 close($output_fh);
 print "New file '$opt_o' has been written.\n";
-



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845463 - /tomcat/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 12:44:09 2018
New Revision: 1845463

URL: http://svn.apache.org/viewvc?rev=1845463&view=rev
Log:
Make sure the two lists TOMCAT_ONLY and TOMCAT_KEEP
are disjoint.

Modified:
tomcat/trunk/res/scripts/check-mime.pl

Modified: tomcat/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/res/scripts/check-mime.pl?rev=1845463&r1=1845462&r2=1845463&view=diff
==
--- tomcat/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/trunk/res/scripts/check-mime.pl Thu Nov  1 12:44:09 2018
@@ -181,6 +181,18 @@ if ($opt_m eq '' || $opt_i eq '' || $opt
 # Switch locale for alphabetical ordering
 setlocale(LC_COLLATE, $LOCALE);
 
+# Check whether TOMCAT_ONLY and TOMCAT_KEEP are disjoint
+for $extension (sort keys %TOMCAT_ONLY) {
+if (exists($TOMCAT_KEEP{$extension})) {
+push(@extensions, ($extension));
+}
+}
+if (@extensions > 0) {
+print STDERR "FATAL Lists TOMCAT_ONLY and TOMCAT_KEEP must be disjoint.\n";
+print STDERR "FATAL Common entries are: " . join(', ', @extensions) . " - 
Aborting!\n";
+exit 6;
+}
+
 # Read and parse httpd mime.types, build up hash extension->mime-type
 open($mimetypes_fh, '<', $opt_m) or die "Could not open file '$opt_m' for read 
- Aborting!";
 while (<$mimetypes_fh>) {



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845465 - /tomcat/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 12:45:44 2018
New Revision: 1845465

URL: http://svn.apache.org/viewvc?rev=1845465&view=rev
Log:
Do no longer tolerate outdated entries in
TOMCAT_ONLY or TOMCAT_KEEP.

Modified:
tomcat/trunk/res/scripts/check-mime.pl

Modified: tomcat/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/res/scripts/check-mime.pl?rev=1845465&r1=1845464&r2=1845465&view=diff
==
--- tomcat/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/trunk/res/scripts/check-mime.pl Thu Nov  1 12:45:44 2018
@@ -333,6 +333,54 @@ while (<$webxml_fh>) {
 close($webxml_fh);
 
 
+# Look for extensions in TOMCAT_ONLY.
+# Abort if it already exists in mime.types.
+# Warn if they are no longer existing in web.xml.
+for $extension (sort keys %TOMCAT_ONLY) {
+if (exists($httpd{$extension})) {
+if ($httpd{$extension} eq $TOMCAT_ONLY{$extension}) {
+print STDERR "FATAL Consistent definition for '$extension' -> 
'$TOMCAT_ONLY{$extension}' exists in mime.types.\n";
+print STDERR "FATAL You must remove '$extension' from the 
TOMCAT_ONLY list - Aborting!\n";
+exit 7;
+} else {
+print STDERR "FATAL Definition '$extension' -> 
'$httpd{$extension}' exists in mime.types but\n";
+print STDERR "FATAL differs from '$extension' -> 
'$TOMCAT_ONLY{$extension}' in TOMCAT_ONLY.\n";
+print STDERR "FATAL You must either remove '$extension' from the 
TOMCAT_ONLY list to keep the mime.types variant,\n";
+print STDERR "FATAL or move it to TOMCAT_KEEP to overwrite the 
mime.types variant - Aborting!\n";
+exit 8;
+}
+}
+if (!exists($tomcat{$extension})) {
+print STDERR "WARN Additional extension '$extension' allowed by 
TOMCAT_ONLY list, but not found in web.xml\n";
+print STDERR "WARN Definition '$extension' -> 
'$TOMCAT_ONLY{$extension}' will be added again to generated web.xml.\n";
+print STDERR "WARN Consider removing it from TOMCAT_ONLY if you do not 
want to add back this extension.\n";
+}
+}
+
+
+# Look for extensions in TOMCAT_KEEP.
+# Abort if they do not exist in mime.types or have the same definition there..
+# Warn if they are no longer existing in web.xml.
+for $extension (sort keys %TOMCAT_KEEP) {
+if (exists($httpd{$extension})) {
+if ($httpd{$extension} eq $TOMCAT_KEEP{$extension}) {
+print STDERR "FATAL Consistent definition for '$extension' -> 
'$TOMCAT_KEEP{$extension}' exists in mime.types.\n";
+print STDERR "FATAL You must remove '$extension' from the 
TOMCAT_KEEP list - Aborting!\n";
+exit 9;
+}
+} else {
+print STDERR "WARN Definition '$extension' -> 
'$TOMCAT_KEEP{$extension}' does not exist in mime.types,\n";
+print STDERR "FATAL so you must move it from TOMCAT_KEEP to 
TOMCAT_ONLY - Aborting!\n";
+exit 10;
+}
+if (!exists($tomcat{$extension})) {
+print STDERR "WARN Additional extension '$extension' allowed by 
TOMCAT_KEEP list, but not found in web.xml\n";
+print STDERR "WARN Definition '$extension' -> 
'$TOMCAT_KEEP{$extension}' will be added again to generated web.xml.\n";
+print STDERR "WARN Consider removing it from TOMCAT_KEEP if you do not 
want to add back this extension.\n";
+}
+}
+
+
 # Look for extensions existing for Tomcat but not for httpd.
 # Log them if they are not in TOMCAT_ONLY
 for $extension (@tomcat_extensions) {



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845469 - /tomcat/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 13:00:21 2018
New Revision: 1845469

URL: http://svn.apache.org/viewvc?rev=1845469&view=rev
Log:
hqx and m4a no longer needed in TOMCAT_ONLY.
The same definitions are now part of httpd's mime.types.

Modified:
tomcat/trunk/res/scripts/check-mime.pl

Modified: tomcat/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/res/scripts/check-mime.pl?rev=1845469&r1=1845468&r2=1845469&view=diff
==
--- tomcat/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/trunk/res/scripts/check-mime.pl Thu Nov  1 13:00:21 2018
@@ -79,11 +79,9 @@ my %TOMCAT_ONLY = qw(
 dv video/x-dv
 flac audio/flac
 gz application/x-gzip
-hqx application/mac-binhex40
 htc text/x-component
 jsf text/plain
 jspf text/plain
-m4a audio/mp4
 m4b audio/mp4
 m4r audio/mp4
 mp1 audio/mpeg



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845472 - /tomcat/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 13:01:40 2018
New Revision: 1845472

URL: http://svn.apache.org/viewvc?rev=1845472&view=rev
Log:
Move flac from TOMCAT_ONLY, because it has
now shown up in httpd's mime.types but with
a different value (audio/x-flac instead of our
audio/flac). For now stick to our decision.

Modified:
tomcat/trunk/res/scripts/check-mime.pl

Modified: tomcat/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/res/scripts/check-mime.pl?rev=1845472&r1=1845471&r2=1845472&view=diff
==
--- tomcat/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/trunk/res/scripts/check-mime.pl Thu Nov  1 13:01:40 2018
@@ -77,7 +77,6 @@ my %TOMCAT_ONLY = qw(
 body text/html
 dib image/bmp
 dv video/x-dv
-flac audio/flac
 gz application/x-gzip
 htc text/x-component
 jsf text/plain
@@ -106,6 +105,7 @@ my %TOMCAT_KEEP = qw(
 cdf application/x-cdf
 class application/java
 exe application/octet-stream
+flac audio/flac
 m4v video/mp4
 mif application/x-mif
 pct image/pict



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: Mime types

2018-11-01 Thread Rainer Jung

Am 31.10.2018 um 20:15 schrieb Konstantin Kolinko:

ср, 31 окт. 2018 г. в 19:38, Rémy Maucherat :

...

And then all the badly maintained content from web.xml and the Tomcat class
can be deleted.

Comments ?


1. "badly maintained content from web.xml"

Do not call them "bad".

AFAIK, Those are synchronized with httpd. IIRC there was python script
to check the sync. Technically, it should be possible to sync with
IANA registry.

(I do not remember the details - those should be easy to find in the
archives of this mailing list. I just remember that the last time that
the sync was checked, there was some good job done to automate and
perform the check.)


Here's what I had originally prepare (script, but not automated):

% res/scripts/check-mime.pl --help
trunk-veryclean2/res/scripts/check-mime.pl version 1.1 calling 
Getopt::Std::getopts (version 1.05),

running under Perl version 5.8.4.
Usage:: res/scripts/check-mime.pl -m MIMEFILE -i INPUTFILE -o OUTPUTFILE
   MIMEFILE:   path to mime.types from the httpd project
   INPUTFILE:  path to existing web.xml, which will be checked
   OUTPUTFILE: path to the new (generated) web.xml. Any existing
   file will be overwritten.

% res/scripts/check-mime.pl -m /shared/build/dev/httpd/svn/httpd \
/path/to/mime.types -i conf/web.xml -o conf/web.xml-new
FATAL Definition 'flac' -> 'audio/x-flac' exists in mime.types but
FATAL differs from 'flac' -> 'audio/flac' in TOMCAT_ONLY.
FATAL You must either remove 'flac' from the TOMCAT_ONLY list to keep 
the mime.types variant,
FATAL or move it to TOMCAT_KEEP to overwrite the mime.types variant - 
Aborting!


OK, so that means we originally had "flac" in our web.xml, but httpd had 
none. In the meantime httpd added it as audio/x-flac, but we had 
audio/flac, so we need to decide between the two.


in httpd the change was (svn log):

r1301894 | fielding | 2012-03-17 09:58:59 +0100 (Sat, 17 Mar 2012) | 2 lines
Unregistered media types in common use, according to Wikipedia and MS

Doing a little search does not result in any of the two variants being 
obviously correct. So for now I add audio/flac to TOMCAT_KEEP and we 
stick to our decision (done in 1845472).


And then:

% res/scripts/check-mime.pl -m /shared/build/dev/httpd/svn/httpd \
/path/to/mime.types -i conf/web.xml -o conf/web.xml-new
New file 'conf/web.xml-new' has been written.

% diff -u  conf/web.xmlconf/web.xml-new

No output, so no changes, nothing to update.

Regards,

Rainer

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845473 - /tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 13:07:22 2018
New Revision: 1845473

URL: http://svn.apache.org/viewvc?rev=1845473&view=rev
Log:
- Simplify script description.

- Make sure the two lists TOMCAT_ONLY and TOMCAT_KEEP
are disjoint.

- Do no longer tolerate outdated entries in
TOMCAT_ONLY or TOMCAT_KEEP.

- hqx and m4a no longer needed in TOMCAT_ONLY.
The same definitions are now part of httpd's mime.types.

- Move flac from TOMCAT_ONLY, because it has
now shown up in httpd's mime.types but with
a different value (audio/x-flac instead of our
audio/flac). For now stick to our decision.

Backports of r1845472, r1845469, r1845465,
r1845463 and r1845462 from trunk.

Modified:
tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl

Modified: tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl
URL: 
http://svn.apache.org/viewvc/tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl?rev=1845473&r1=1845472&r2=1845473&view=diff
==
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Nov  1 13:09:31 2018
@@ -1,2 +1,2 @@
 /tomcat/tc8.0.x/trunk:1809644
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737903,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739492,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409
 
,1741501,1741677,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744149,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745083,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745473,1745535,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028,1747035,1747210,1747225,1747234,1747253,1747
 
404,1747506,1747536,1747924,1747980,1747993,1748001,1748253,1748452,1748547,1748629,1748676,1748715,1749287,1749296,1749328,1749373,1749465,1749506,1749508,1749665-1749666,1749763,1749865-1749866,1749898,1749978,1749980,1750011,1750015,1750056,1750480,1750617,1750634,1750692,1750697,1750700,1750703,1750707,1750714,1750718,1750723,1750774,1750899,1750975,1750995,1751061,1751097,1751173,1751438,1751447,1751463,1751702,1752212,1752737,1752745,1753078,1753080,1753358,1753363,1754111,1754140-1754141,1754281,1754310,1754445,1754467,1754494,1754496,1754528,1754532-1754533,1754613,1754714,1754874,1754941,1754944,1754950-1754951,1755005,1755007,1755009,1755132,1755180-1755181,1755185,1755190,1755204-1755206,1755208,1755214,1755224,1755227,1755230,1755629,1755646-1755647,1755650,1755653,1755675,1755680,1755683,1755693,1755717,1755731-1755737,1755812,1755828,1755884,1755890,1755918-1755919,1755942,1755958,1755960,1755970,1755993,1756013,1756019,1756039,1756056,1756083-1756114,1756175,1756288-1
 
756289,1756408-1756410,1756778,1756798,1756878,1756898,1756939,1757123-1757124,1757126,1757128,1757132-1757133,1757136,1757145,1757167-1757168,1757175,1757180,1757182,1757195,1757271,1757278,1757347,1757353-1757354,1757363,1757374,1757399,1757406,1757408,1757485,1757495,1757499,1757527,1757578,1757684,1757722,1757727,1757790,1757799,1757813,1757853,1757883,1757903,1757976,1757997,1758000,1758058,1758072-1758075,1758078-1758079,1758223,1758257,1758261,1758276,1758292,1758369,1758378-1758383,1758421,1758423,1758425-1758427,1758430,1758443,1758448,1758459,1758483,1758486-1758487,1758499,1758525,1758556,1758580,1758582,1758584,1758588,1758842,1759019,1759212,1759224,1759227,1759252,1759274,1759513-1759516,1759611,1759757,1759785-1759790,1760005,1760022,1760109-1760110,1760135,1760200-1760201,1760227,1760300,1760397,1760446,1760454,1760640,1760648,1761057,1761422,1761491,1761498,1761500-1761501,1761550,1761553,1761572,1761574,1761625-1761626,1761628,1761682,1761740,1761752,1762051-176205
 
3,1762123,1762168,1762172,1762182,1762201-1762202,1762204,1762208,1762288,1762296,1762324,1762348,1762353,1762362,1762374,1762492,1762503,1762505,1762541,1762608,1762710,1762753,1762766,1762769,1762944,1762947,1762953,1763167,1763179,1763232,1763259,1763271-1763272,1763276-1763277,1763319-1763320,1763370,1763372,1763375,1763377,1763393,1763412,1763430,1763450,1763462,1763505,1763511-1763512,1763516,1763518,1763520,1763529,1763559,1763565,1763568,1763574,1763619,1763634-1763635,1763718,1763748,1763786,1763798-1763799,1763810,1763813,1763815,1763819,

svn commit: r1845475 - in /tomcat/tc7.0.x/trunk: ./ res/scripts/check-mime.pl

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 13:13:41 2018
New Revision: 1845475

URL: http://svn.apache.org/viewvc?rev=1845475&view=rev
Log:
- Simplify script description.

- Make sure the two lists TOMCAT_ONLY and TOMCAT_KEEP
are disjoint.

- Do no longer tolerate outdated entries in
TOMCAT_ONLY or TOMCAT_KEEP.

- hqx and m4a no longer needed in TOMCAT_ONLY.
The same definitions are now part of httpd's mime.types.

- Move flac from TOMCAT_ONLY, because it has
now shown up in httpd's mime.types but with
a different value (audio/x-flac instead of our
audio/flac). For now stick to our decision.

Backports of r1845472, r1845469, r1845465,
r1845463 and r1845462 from trunk resp.
r1845473 and r1845474 from tc8.5.x.

Modified:
tomcat/tc7.0.x/trunk/   (props changed)
tomcat/tc7.0.x/trunk/res/scripts/check-mime.pl

Propchange: tomcat/tc7.0.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Nov  1 13:13:41 2018
@@ -1,3 +1,3 @@
 
/tomcat/tc8.0.x/trunk:1636525,1637336,1637685,1637709,1638726,1640089,1640276,1640349,1640363,1640366,1640642,1640672,1640674,1640689,1640884,1641001,1641065,1641067,1641375,1641638,1641723,1641726,1641729-1641730,1641736,1641988,1642669-1642670,1642698,1642701,1643205,1643215,1643217,1643230,1643232,1643273,1643285,1643329-1643330,1643511,1643513,1643521,1643539,1643571,1643581-1643582,1643635,1643655,1643738,1643964,1644018,1644333,1644525,1644954,1644992,1645014,1645360,1645456,1645627,1645642,1645686,1645903-1645904,1645908-1645909,1645913,1645920,1646458,1646460-1646462,1646735,1646738-1646741,1646744,1646746,1646748-1646755,1646757,1646759-1646760,1647043,1648816,1651420-1651422,1651844,1652926,1652939-1652940,1652973,1653798,1653817,1653841,1654042,1654161,1654736,1654767,1654787,1656592,1659907,1662986,1663265,1663278,1663325,1663535,1663567,1663679,1663997,1664175,1664321,1664872,1665061,1665086,1666027,1666395,1666503,1666506,1666560,1666570,1666581,1666759,1666967,1666988
 
,1667553-1667555,1667558,1667617,1667633,1667637,1667747,1667767,1667873,1668028,1668137,1668634,1669432,1669801,1669840,1669895-1669896,1670398,1670435,1670592,1670605-1670607,1670609,1670632,1670720,1670725,1670727,1670731,1671114,1672273,1672285,1673759,1674220,1674295,1675469,1675488,1675595,1675831,1676232,1676367-1676369,1676382,1676394,1676483,1676556,1676635,1678178,1679536,1679988,1680256,1681124,1681182,1681703,1681730,1681840,1681864,1681869,1682010,1682034,1682047,1682052-1682053,1682062,1682064,1682070,1682312,1682325,1682331,1682386,1684367,1684385,1685759,1685774,1685827,1685892,1687341,1688904,1689358,1689657,1689921,1692850,1693093,1693108,1693324,1694060,1694115,1694291,1694427,1694431,1694503,1694549,1694789,1694873,1694881,1695356,1695372,1695823-1695825,1696200,1696281,1696379,1696468,1700608,1700871,1700897,1700978,1701094,1701124,1701608,1701668,1701676,1701766,1701944,1702248,1702252,1702314,1702390,1702723,1702725,1702728,1702730,1702733,1702735,1702737,1702
 
739,1702742,1702744,1702748,1702751,1702754,1702758,1702760,1702763,1702766,1708779,1708782,1708806,1709314,1709670,1710347,1710442,1710448,1710490,1710574,1710578,1712226,1712229,1712235,1712255,1712618,1712649,1712655,1712860,1712899,1712903,1712906,1712913,1712926,1712975,1713185,1713262,1713287,1713613,1713621,1713872,1713976,1713994,1713998,1714004,1714013,1714059,1714538,1714580,1715189,1715207,1715544,1715549,1715637,1715639-1715645,1715667,1715683,1715866,1715978,1715981,1716216-1716217,1716355,1716414,1716421,1717208-1717209,1717257,1717283,1717288,1717291,1717421,1717517,1717529,1718797,1718840-1718843,1719348,1719357-1719358,1719400,1719491,1719737,1720235,1720396,1720442,1720446,1720450,1720463,1720658-1720660,1720756,1720816,1721813,1721818,1721831,1721861,1721867,1721882,1722523,1722527,1722800,1722926,1722941,1722997,1723130,1723440,1723488,1723890,1724434,1724674,1724792,1724803,1724902,1725128,1725131,1725154,1725167,1725911,1725921,1725929,1725963-1725965,1725970,1
 
725974,1726171-1726173,1726175,1726179-1726182,1726190-1726191,1726195-1726200,1726203,1726226,1726576,1726630,1726992,1727029,1727037,1727671,1727676,1727900,1728028,1728092,1728439,1728449,1729186,1729362,1731009,1731303,1731867,1731872,1731874,1731876,1731885,1731947,1731955,1731959,1731977,1731984,1732360,1732490,1732672,1732902,1733166,1733603,1733619,1733735,1733752,1733764,1733915,1733941,1733964,1734115,1734133,1734261,1734421,1734531,1736286,1737967,1738173,1738182,1738992,1739039,1739089-1739091,1739294,1739777,1739821,1739981,1740513,1740726,1741019,1741162,1741217,1743647,1743681,1744152,1744272,1746732,1746750,1752739,1754615,1755886,1756018,1758563,1759565,1761686,1762173,1762206,1766280,1767507-1767508,1767653,1767656,1769267,1772949,1773521,1773527,1774104,1777015,1777213,1779330,1783151,1784188,1784966,1785670,1786846,1788260,1788999,1789140,1789402,1791529,1791559,1795291,1796906,1797523,1799214,1800998-1800999,1801003,1801007-1801008,1801017,1801020,

Re: Mime types

2018-11-01 Thread Christopher Schultz
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA256

Rémy,

On 10/31/18 12:37, Rémy Maucherat wrote:
> There are two main contraptions in Tomcat that do (badly ...)
> extension to mime type mapping: the shared web.xml and some
> hardcoded stuff in startup.Tomcat.

It would probably be good to unify all that code, regardless of what
else we do.

> While we should obviously have support for user configured mime
> types in web.xml, as it's the spec, there should be a possibility
> to use Files.probeContentType as the fallback when a mime type
> isn't found (and maybe also have an option to disable it ? -
> although I don't quite see why it would bother anyone).

Why bother even doing that? File-extension mapping is a poor way to
perform file-type detection (in fact, it is NOT file type detection),
but the spec mandates it, so we are stuck.

But why bother providing container-managed file-type detection? Seems
like useless cruft to me.

> After looking at its implementation, it looks into all mime type 
> locations we might want (the OS, a mime.types file, etc). The only 
> problem is that it uses a Path (that would be an issue since it's 
> super tied to a real filesystem), but thankfully it mostly uses 
> toString and thus can be worked around using a new fake Path 
> implementation.> The code calling Files.probeContentType could be 
> inserted here in DefaultServlet:
> 
> // Find content type. String contentType = resource.getMimeType(); 
> if (contentType == null) { contentType = 
> getServletContext().getMimeType(resource.getName()); ---> 
> resource.setMimeType(contentType); }
> 
> And then all the badly maintained content from web.xml and the
> Tomcat class can be deleted.
> 
> Comments ?

Even a benign library like libmagic has had a bunch of
vulnerabilities[1] over the years: provide a specially-crafted file
and you can do Bad Things.

If applications want to do this to themselves, why not let them do it
independently?

- -chris

[1]
https://www.cvedetails.com/product/22647/Tim-Robbins-Libmagic.html?vendo
r_id=12061
-BEGIN PGP SIGNATURE-
Comment: Using GnuPG with Thunderbird - https://www.enigmail.net/

iQIzBAEBCAAdFiEEMmKgYcQvxMe7tcJcHPApP6U8pFgFAlvbAOAACgkQHPApP6U8
pFg5gw/9EfWNeXueSYS4bwHRR4IYA3COPGRuuepayAABIEOTNO1ZY1O+KZu39y/t
52GxR6tl6WvJxJ3FXkgqP9QrEAIAiDQwNTqj2OsragyFiE5jnIj5lRsZER9JWJmy
fjKRAMV3UOqSOYceU0PaXGOmnije5IU3rhO/ZQIMcZToXPPevI8RyM1QPpGDQGvt
9y1OkVfeaHcaIQuYEN/ue0u3U4ARt/s4JwkSf1LJCIqgc5on4Cj/pAtcDOhSG4cN
ILsJmcuJDsbPaaBp8VkNw6gaQsMitZ8H8cAtovkMB8RdpSpgtL/EeN4NTdDaXgoR
EzP5hrhrx20jpgLjVfLW1NI/7F+Ek+IYHwUdNcAy2oDQaEO8tVeRh9D0O8V8Dk+T
czFgoSq0MajlmWSzlRSCmhGVd7xxaYhaVH0PThTMLVKkF/QWafzrZQZXJ30oLXQv
iDnvJ5rXP87WamtSlXL+KvDTJSK8stJwCZAFRJEz67hxTSKG60yByvN134yP4E4i
4TdXGmvHnexqdPJ7/+Eymf6ESgAEW0IuH2DHnWaKQGtc2TZeLSK1Gp4m9zjS0Ojl
wsWwgiO4vDFddLZZvoa1shnE964uufES/DLe92TbnfIpRk6GoT85tlojKSMDsBhV
56ce0jWim4c7mf9QGbe25Hf/rf6ooCRwj2TU/WBUy+aYg+v2xH4=
=caWD
-END PGP SIGNATURE-

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot failure in on tomcat-trunk

2018-11-01 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-trunk while building 
. Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/3698

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1845472
Blamelist: rjung

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845482 - in /tomcat/trunk: java/org/apache/catalina/ java/org/apache/catalina/connector/ java/org/apache/catalina/core/ java/org/apache/catalina/mbeans/ java/org/apache/catalina/realm/ j

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 15:06:53 2018
New Revision: 1845482

URL: http://svn.apache.org/viewvc?rev=1845482&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=61171
Add the portOffset attribute to the Server element which is added to the 
configured shutdown and Connector ports.
Based on a patch by Marek Czernek.
THis closes #125

Added:
tomcat/trunk/java/org/apache/catalina/startup/AddPortOffsetRule.java   
(with props)
Modified:
tomcat/trunk/java/org/apache/catalina/Server.java
tomcat/trunk/java/org/apache/catalina/connector/Connector.java
tomcat/trunk/java/org/apache/catalina/connector/mbeans-descriptors.xml
tomcat/trunk/java/org/apache/catalina/core/LocalStrings.properties
tomcat/trunk/java/org/apache/catalina/core/StandardServer.java
tomcat/trunk/java/org/apache/catalina/core/mbeans-descriptors.xml
tomcat/trunk/java/org/apache/catalina/mbeans/MBeanFactory.java
tomcat/trunk/java/org/apache/catalina/realm/RealmBase.java
tomcat/trunk/java/org/apache/catalina/startup/Catalina.java
tomcat/trunk/java/org/apache/catalina/startup/LocalStrings.properties
tomcat/trunk/java/org/apache/catalina/valves/RemoteAddrValve.java
tomcat/trunk/java/org/apache/catalina/valves/RemoteHostValve.java
tomcat/trunk/java/org/apache/coyote/AbstractProtocol.java
tomcat/trunk/java/org/apache/coyote/LocalStrings.properties
tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java
tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java
tomcat/trunk/java/org/apache/tomcat/util/net/LocalStrings.properties
tomcat/trunk/java/org/apache/tomcat/util/net/Nio2Endpoint.java
tomcat/trunk/java/org/apache/tomcat/util/net/NioEndpoint.java
tomcat/trunk/webapps/docs/changelog.xml
tomcat/trunk/webapps/docs/config/server.xml

Modified: tomcat/trunk/java/org/apache/catalina/Server.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/Server.java?rev=1845482&r1=1845481&r2=1845482&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/Server.java (original)
+++ tomcat/trunk/java/org/apache/catalina/Server.java Thu Nov  1 15:06:53 2018
@@ -73,6 +73,9 @@ public interface Server extends Lifecycl
 
 /**
  * @return the port number we listen to for shutdown commands.
+ *
+ * @see #getPortOffset()
+ * @see #getPortWithOffset()
  */
 public int getPort();
 
@@ -81,9 +84,37 @@ public interface Server extends Lifecycl
  * Set the port number we listen to for shutdown commands.
  *
  * @param port The new port number
+ *
+ * @see #setPortOffset(int)
  */
 public void setPort(int port);
 
+/**
+ * Get the number that offsets the port used for shutdown commands.
+ * For example, if port is 8005, and portOffset is 1000,
+ * the server listens at 9005.
+ *
+ * @return the port offset
+ */
+public int getPortOffset();
+
+/**
+ * Set the number that offsets the server port used for shutdown commands.
+ * For example, if port is 8005, and you set portOffset to 1000,
+ * connector listens at 9005.
+ *
+ * @param portOffset sets the port offset
+ */
+public void setPortOffset(int portOffset);
+
+/**
+ * Get the actual port on which server is listening for the shutdown 
commands.
+ * If you do not set port offset, port is returned. If you set
+ * port offset, port offset + port is returned.
+ *
+ * @return the port with offset
+ */
+public int getPortWithOffset();
 
 /**
  * @return the address on which we listen to for shutdown commands.

Modified: tomcat/trunk/java/org/apache/catalina/connector/Connector.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/connector/Connector.java?rev=1845482&r1=1845481&r2=1845482&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/connector/Connector.java (original)
+++ tomcat/trunk/java/org/apache/catalina/connector/Connector.java Thu Nov  1 
15:06:53 2018
@@ -536,6 +536,37 @@ public class Connector extends Lifecycle
 }
 
 
+public int getPortOffset() {
+// Try shortcut that should work for nearly all uses first as it does
+// not use reflection and is therefore faster.
+if (protocolHandler instanceof AbstractProtocol) {
+return ((AbstractProtocol) protocolHandler).getPortOffset();
+}
+// Fall back for custom protocol handlers not based on AbstractProtocol
+Object port = getProperty("portOffset");
+if (port instanceof Integer) {
+return ((Integer) port).intValue();
+}
+// Usually means an invalid protocol has been configured.
+return 0;
+}
+
+
+public void setPortOffset(int portOffset) {
+setProperty("portOffset", String.valueOf(port

[GitHub] tomcat pull request #125: Provide port offset functionality (BZ-61171)

2018-11-01 Thread asfgit
Github user asfgit closed the pull request at:

https://github.com/apache/tomcat/pull/125


---

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] tomcat issue #125: Provide port offset functionality (BZ-61171)

2018-11-01 Thread markt-asf
Github user markt-asf commented on the issue:

https://github.com/apache/tomcat/pull/125
  
Patch has been applied with a few changes:
 - portOffset was not cached on the Connector (to align with recent changes 
to how port is handled)
 - handle special case port values where the offset should not be applied
 - use getPortWithOffset() everywhere
 - expose  new attributes via JMX
 - take a slightly different approach with logging in case anyone (not  
that they should) is parsing log messages based on the current format
 - added handling for the redirectPort attribute
 - fix any IDE / CheckStyle warnings

Despite what might look like a long list of changes, the patch was applied 
largely as-is. I particularly like the approach to handling the Connectors.

Many thanks. This feature will be available in 9.0.13 onwards.


---

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 61171] Add port offset attribute (portOffset?) to Server configuration in server.xml

2018-11-01 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=61171

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |FIXED

--- Comment #8 from Mark Thomas  ---
Provide patch applied (with a few changes) to 9.0.x for 9.0.13 onwards.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: Mime types

2018-11-01 Thread Rémy Maucherat
On Thu, Nov 1, 2018 at 2:34 PM Christopher Schultz <
ch...@christopherschultz.net> wrote:

> Why bother even doing that? File-extension mapping is a poor way to
> perform file-type detection (in fact, it is NOT file type detection),
> but the spec mandates it, so we are stuck.
>
> But why bother providing container-managed file-type detection? Seems
> like useless cruft to me.
>

Well, some users want it.

Anyway, I get the idea that the feature add isn't very popular, so I'll
forget about it.

Rémy


buildbot success in on tomcat-trunk

2018-11-01 Thread buildbot
The Buildbot has detected a restored build on builder tomcat-trunk while 
building . Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/3699

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1845482
Blamelist: markt

Build succeeded!

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] tomcat issue #130: Add two spaces (nbsp) in front of the Undeploy button

2018-11-01 Thread markt-asf
Github user markt-asf commented on the issue:

https://github.com/apache/tomcat/pull/130
  
I can see what you are trying to do but I'm not sure the change creates 
enough of a visual separation to make much of a difference. I don't think it 
will do much to reduce the risk of an accidental click.
On the other hand, it would have taken me less time to just apply the 
change than I have spent writing this comment.
I'm going to apply the change as it won't make the issue worse, it might 
help and it is a trivial change.


---

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845489 - in /tomcat/trunk: java/org/apache/catalina/manager/HTMLManagerServlet.java webapps/docs/changelog.xml

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 15:35:46 2018
New Revision: 1845489

URL: http://svn.apache.org/viewvc?rev=1845489&view=rev
Log:
Create a little visual separation between the Undeploy button and the other 
buttons in the Manager application.
Patch provided by Łukasz Jąder.
This closes #130

Modified:
tomcat/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java?rev=1845489&r1=1845488&r2=1845489&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java Thu 
Nov  1 15:35:46 2018
@@ -1205,7 +1205,7 @@ public final class HTMLManagerServlet ex
 "  " +
 "  \n" +
 "  " +
-"  " +
+"    " +
 "  \n" +
 " \n" +
 " \n" +

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1845489&r1=1845488&r2=1845489&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Thu Nov  1 15:35:46 2018
@@ -244,6 +244,11 @@
 will be overwritten by settings specified in a default context file 
such
 as conf/context.xml. (markt)
   
+  
+Create a little visual separation between the Undeploy button and the
+other buttons in the Manager application. Patch provided by Łukasz
+Jąder. (markt)
+  
 
   
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] tomcat pull request #130: Add two spaces (nbsp) in front of the Undeploy but...

2018-11-01 Thread asfgit
Github user asfgit closed the pull request at:

https://github.com/apache/tomcat/pull/130


---

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845490 - in /tomcat/tc8.5.x/trunk: ./ java/org/apache/catalina/manager/HTMLManagerServlet.java webapps/docs/changelog.xml

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 15:36:47 2018
New Revision: 1845490

URL: http://svn.apache.org/viewvc?rev=1845490&view=rev
Log:
Create a little visual separation between the Undeploy button and the other 
buttons in the Manager application.
Patch provided by Łukasz Jąder.

Modified:
tomcat/tc8.5.x/trunk/   (props changed)

tomcat/tc8.5.x/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java
tomcat/tc8.5.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Nov  1 15:36:47 2018
@@ -1,2 +1,2 @@
 /tomcat/tc8.0.x/trunk:1809644
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737903,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739492,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409
 
,1741501,1741677,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744149,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745083,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745473,1745535,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028,1747035,1747210,1747225,1747234,1747253,1747
 
404,1747506,1747536,1747924,1747980,1747993,1748001,1748253,1748452,1748547,1748629,1748676,1748715,1749287,1749296,1749328,1749373,1749465,1749506,1749508,1749665-1749666,1749763,1749865-1749866,1749898,1749978,1749980,1750011,1750015,1750056,1750480,1750617,1750634,1750692,1750697,1750700,1750703,1750707,1750714,1750718,1750723,1750774,1750899,1750975,1750995,1751061,1751097,1751173,1751438,1751447,1751463,1751702,1752212,1752737,1752745,1753078,1753080,1753358,1753363,1754111,1754140-1754141,1754281,1754310,1754445,1754467,1754494,1754496,1754528,1754532-1754533,1754613,1754714,1754874,1754941,1754944,1754950-1754951,1755005,1755007,1755009,1755132,1755180-1755181,1755185,1755190,1755204-1755206,1755208,1755214,1755224,1755227,1755230,1755629,1755646-1755647,1755650,1755653,1755675,1755680,1755683,1755693,1755717,1755731-1755737,1755812,1755828,1755884,1755890,1755918-1755919,1755942,1755958,1755960,1755970,1755993,1756013,1756019,1756039,1756056,1756083-1756114,1756175,1756288-1
 
756289,1756408-1756410,1756778,1756798,1756878,1756898,1756939,1757123-1757124,1757126,1757128,1757132-1757133,1757136,1757145,1757167-1757168,1757175,1757180,1757182,1757195,1757271,1757278,1757347,1757353-1757354,1757363,1757374,1757399,1757406,1757408,1757485,1757495,1757499,1757527,1757578,1757684,1757722,1757727,1757790,1757799,1757813,1757853,1757883,1757903,1757976,1757997,1758000,1758058,1758072-1758075,1758078-1758079,1758223,1758257,1758261,1758276,1758292,1758369,1758378-1758383,1758421,1758423,1758425-1758427,1758430,1758443,1758448,1758459,1758483,1758486-1758487,1758499,1758525,1758556,1758580,1758582,1758584,1758588,1758842,1759019,1759212,1759224,1759227,1759252,1759274,1759513-1759516,1759611,1759757,1759785-1759790,1760005,1760022,1760109-1760110,1760135,1760200-1760201,1760227,1760300,1760397,1760446,1760454,1760640,1760648,1761057,1761422,1761491,1761498,1761500-1761501,1761550,1761553,1761572,1761574,1761625-1761626,1761628,1761682,1761740,1761752,1762051-176205
 
3,1762123,1762168,1762172,1762182,1762201-1762202,1762204,1762208,1762288,1762296,1762324,1762348,1762353,1762362,1762374,1762492,1762503,1762505,1762541,1762608,1762710,1762753,1762766,1762769,1762944,1762947,1762953,1763167,1763179,1763232,1763259,1763271-1763272,1763276-1763277,1763319-1763320,1763

svn commit: r1845491 - in /tomcat/tc7.0.x/trunk: ./ java/org/apache/catalina/manager/HTMLManagerServlet.java webapps/docs/changelog.xml

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 15:37:22 2018
New Revision: 1845491

URL: http://svn.apache.org/viewvc?rev=1845491&view=rev
Log:
Create a little visual separation between the Undeploy button and the other 
buttons in the Manager application.
Patch provided by Łukasz Jąder.

Modified:
tomcat/tc7.0.x/trunk/   (props changed)

tomcat/tc7.0.x/trunk/java/org/apache/catalina/manager/HTMLManagerServlet.java
tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc7.0.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Nov  1 15:37:22 2018
@@ -1,3 +1,3 @@
 
/tomcat/tc8.0.x/trunk:1636525,1637336,1637685,1637709,1638726,1640089,1640276,1640349,1640363,1640366,1640642,1640672,1640674,1640689,1640884,1641001,1641065,1641067,1641375,1641638,1641723,1641726,1641729-1641730,1641736,1641988,1642669-1642670,1642698,1642701,1643205,1643215,1643217,1643230,1643232,1643273,1643285,1643329-1643330,1643511,1643513,1643521,1643539,1643571,1643581-1643582,1643635,1643655,1643738,1643964,1644018,1644333,1644525,1644954,1644992,1645014,1645360,1645456,1645627,1645642,1645686,1645903-1645904,1645908-1645909,1645913,1645920,1646458,1646460-1646462,1646735,1646738-1646741,1646744,1646746,1646748-1646755,1646757,1646759-1646760,1647043,1648816,1651420-1651422,1651844,1652926,1652939-1652940,1652973,1653798,1653817,1653841,1654042,1654161,1654736,1654767,1654787,1656592,1659907,1662986,1663265,1663278,1663325,1663535,1663567,1663679,1663997,1664175,1664321,1664872,1665061,1665086,1666027,1666395,1666503,1666506,1666560,1666570,1666581,1666759,1666967,1666988
 
,1667553-1667555,1667558,1667617,1667633,1667637,1667747,1667767,1667873,1668028,1668137,1668634,1669432,1669801,1669840,1669895-1669896,1670398,1670435,1670592,1670605-1670607,1670609,1670632,1670720,1670725,1670727,1670731,1671114,1672273,1672285,1673759,1674220,1674295,1675469,1675488,1675595,1675831,1676232,1676367-1676369,1676382,1676394,1676483,1676556,1676635,1678178,1679536,1679988,1680256,1681124,1681182,1681703,1681730,1681840,1681864,1681869,1682010,1682034,1682047,1682052-1682053,1682062,1682064,1682070,1682312,1682325,1682331,1682386,1684367,1684385,1685759,1685774,1685827,1685892,1687341,1688904,1689358,1689657,1689921,1692850,1693093,1693108,1693324,1694060,1694115,1694291,1694427,1694431,1694503,1694549,1694789,1694873,1694881,1695356,1695372,1695823-1695825,1696200,1696281,1696379,1696468,1700608,1700871,1700897,1700978,1701094,1701124,1701608,1701668,1701676,1701766,1701944,1702248,1702252,1702314,1702390,1702723,1702725,1702728,1702730,1702733,1702735,1702737,1702
 
739,1702742,1702744,1702748,1702751,1702754,1702758,1702760,1702763,1702766,1708779,1708782,1708806,1709314,1709670,1710347,1710442,1710448,1710490,1710574,1710578,1712226,1712229,1712235,1712255,1712618,1712649,1712655,1712860,1712899,1712903,1712906,1712913,1712926,1712975,1713185,1713262,1713287,1713613,1713621,1713872,1713976,1713994,1713998,1714004,1714013,1714059,1714538,1714580,1715189,1715207,1715544,1715549,1715637,1715639-1715645,1715667,1715683,1715866,1715978,1715981,1716216-1716217,1716355,1716414,1716421,1717208-1717209,1717257,1717283,1717288,1717291,1717421,1717517,1717529,1718797,1718840-1718843,1719348,1719357-1719358,1719400,1719491,1719737,1720235,1720396,1720442,1720446,1720450,1720463,1720658-1720660,1720756,1720816,1721813,1721818,1721831,1721861,1721867,1721882,1722523,1722527,1722800,1722926,1722941,1722997,1723130,1723440,1723488,1723890,1724434,1724674,1724792,1724803,1724902,1725128,1725131,1725154,1725167,1725911,1725921,1725929,1725963-1725965,1725970,1
 
725974,1726171-1726173,1726175,1726179-1726182,1726190-1726191,1726195-1726200,1726203,1726226,1726576,1726630,1726992,1727029,1727037,1727671,1727676,1727900,1728028,1728092,1728439,1728449,1729186,1729362,1731009,1731303,1731867,1731872,1731874,1731876,1731885,1731947,1731955,1731959,1731977,1731984,1732360,1732490,1732672,1732902,1733166,1733603,1733619,1733735,1733752,1733764,1733915,1733941,1733964,1734115,1734133,1734261,1734421,1734531,1736286,1737967,1738173,1738182,1738992,1739039,1739089-1739091,1739294,1739777,1739821,1739981,1740513,1740726,1741019,1741162,1741217,1743647,1743681,1744152,1744272,1746732,1746750,1752739,1754615,1755886,1756018,1758563,1759565,1761686,1762173,1762206,1766280,1767507-1767508,1767653,1767656,1769267,1772949,1773521,1773527,1774104,1777015,1777213,1779330,1783151,1784188,1784966,1785670,1786846,1788260,1788999,1789140,1789402,1791529,1791559,1795291,1796906,1797523,1799214,1800998-1800999,1801003,1801007-1801008,1801017,1801020,1802808,180281
 
4,1803618,1806107,1806733,1807082-1807083,1808707,1808884,1809267,1809644,1809832,1809904,1809915,1809924,1810283,1810328,1810574,1810576-1810577,1810584,1810588,1811141,1811842,1812090,1812096,1812150,1812511,1814976,1814983,1815072,1815453,1815946,1815957,1816143,1816682,1817229,1817287,1820200,1820209,1820283,1820305,1821303-18

[Bug 62873] Tomcat Monitor application will update multi-string values in Windows registry with blank lines

2018-11-01 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=62873

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |MOVED
 OS||All

--- Comment #1 from Mark Thomas  ---
This issue needs to be created against Apache Commons Daemon which is the
component that provides the Windows Service Wrapper for Apache Tomcat.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot failure in on tomcat-trunk

2018-11-01 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-trunk while building 
. Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/3700

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1845489
Blamelist: markt

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: JDK 12 Early Access build 15 is available

2018-11-01 Thread Mark Thomas
On 31/10/2018 08:43, Rory O'Donnell wrote:
> Hi Mark,
> 
> Can you send us the JI-number when you get time to log a bug ?

I would, but it turns out the root cause is in the Tomcat tests. We are
trying to do post-handshake authentication and JDK 11 defaults to TLS
v1.3 and the JSSE TLSv1.3 implementation doesn't implement that feature.

As an aside, this is going to cause problems with JavaEE and JakartaEE
implementations at some point as the Servlet specification effectively
requires that JSSE supports PHA.

Mark


> 
> Rgds,Rory
> 
> 
> On 30/10/2018 17:42, Mark Thomas wrote:
>> FYI,
>>
>> org.apache.tomcat.util.net.TestSsl.testRenegotiateWorks() is failing
>> consistently when running with the NIO2 connector.
>>
>> It works with:
>> - Oracle JDK 1.8.0 update 192
>> - Oracle JDK 9.0.4
>> - Oracle JDK 10.0.2
>>
>> It fails with:
>> - OpenJDK 11.0.1
>> - OpenJDK 12 ea17
>>
>> First impression (based on the results above) is that there is a
>> regression somewhere in JSSE. On the other hand, it works with NIO with
>> all of the above versions which suggests a bug in NIO2.
>>
>> I have not investigated this any further than simply running the test so
>> I have not (yet) opened a bug.
>>
>> Mark
>>
>>
>> On 15/10/18 11:37, Rory O'Donnell wrote:
>>> Hi Mark,
>>>
>>> *JDK 12 Early Access build 15 is available at : - jdk.java.net/12/*
>>>
>>>   * JDK 12 Schedule is confirmed.
>>>   o 2018/12/13 Rampdown Phase One
>>> 
>>>   o 2019/01/17 Rampdown Phase Two
>>> 
>>>   o 2019/02/07 Release-Candidate Phase
>>>     
>>>   o 2019/03/19 General Availability
>>>   * Release Notes for JDK 12 [1]
>>>   * JEPs targeted to JDK 12, so far
>>>   o 325: Switch Expressions (Preview [2]) - Integrated
>>>   o 326: Raw String Literals (Preview [2]) - Integrated
>>>   o 340: One AArch64 Port, Not Two
>>>      - Targeted
>>>   o 341: Default CDS Archives -
>>>     Integrated
>>>   * Important fixes since last email
>>>   o (b15)  Implementation of JEP 341: Default CDS Archives
>>>   o (b14) LDAPS Communication Failure (JDK-8211107
>>>     )
>>>   o (b14) Support dns_canonicalize_hostname in krb5.conf
>>>     (JDK-8210821 )
>>>   o (b14) Removal of com.sun.awt.SecurityWarning Class (JDK-8210692
>>>     )
>>>
>>>
>>> *JDK 8u202 planning [3]*
>>>
>>>   * 8u202 is proposed to be the last Oracle led release for this OpenJDK
>>>     Project.
>>>   * A proposed timeline is as follows :
>>>   o July 2018 8u-dev forest begins collecting 8u202 fixes
>>>   o Mid October 2018 RampDown 2
>>>   o Mid January 2019 GA
>>>
>>> Rgds, Rory
>>>
>>> [1] http://jdk.java.net/12/release-notes
>>> [2] http://openjdk.java.net/jeps/12
>>> [3]
>>> http://mail.openjdk.java.net/pipermail/jdk8u-dev/2018-September/007923.html
>>>
>>>
>>> 
>>>
>>>
>>>
> 


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845495 - /tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 16:14:21 2018
New Revision: 1845495

URL: http://svn.apache.org/viewvc?rev=1845495&view=rev
Log:
Force TLS 1.2 if TLS 1.3 is available as JSSE's TLS 1.3 implementation doesn't 
support Post Handshake Authentication which is required for this test to pass.

Modified:
tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java

Modified: tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java?rev=1845495&r1=1845494&r2=1845495&view=diff
==
--- tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java (original)
+++ tomcat/trunk/test/org/apache/tomcat/util/net/TestSsl.java Thu Nov  1 
16:14:21 2018
@@ -39,6 +39,7 @@ import org.apache.catalina.startup.Teste
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.tomcat.util.buf.ByteChunk;
+import org.apache.tomcat.util.compat.TLS;
 import org.apache.tomcat.websocket.server.WsContextListener;
 
 /**
@@ -109,7 +110,15 @@ public class TestSsl extends TomcatBaseT
 
 tomcat.start();
 
-SSLContext sslCtx = SSLContext.getInstance("TLS");
+SSLContext sslCtx;
+if (TLS.isTlsv13Available()) {
+// Force TLS 1.2 if TLS 1.3 is available as JSSE's TLS 1.3
+// implementation doesn't support Post Handshake Authentication
+// which is required for this test to pass.
+sslCtx = SSLContext.getInstance("TLSv1.2");
+} else {
+sslCtx = SSLContext.getInstance("TLS");
+}
 sslCtx.init(null, TesterSupport.getTrustManagers(), null);
 SSLSocketFactory socketFactory = sslCtx.getSocketFactory();
 SSLSocket socket = (SSLSocket) socketFactory.createSocket("localhost",



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot success in on tomcat-trunk

2018-11-01 Thread buildbot
The Buildbot has detected a restored build on builder tomcat-trunk while 
building . Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/3701

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1845495
Blamelist: markt

Build succeeded!

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 62871] JMX: ThreadPool.socketProperties is not Serializable

2018-11-01 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=62871

--- Comment #1 from Mark Thomas  ---
8.0.x is no longer supported.

If you made a similar change in 8.5.x I'm fairly sure you'd just hit the next
unserializable attribute.

Changing visibility is not really the right solution as it just hides the
information and there is a lot of valuable data in that attribute. Making the
attribute Serializable is one option but that requires that either the class is
present on the JMX client's class path or RMI is enabled to load the class
remotely.

In this instance, making SocketProperties Serializable will just move the
problem as a bunch of its attributes will then fail. Creating a separate MBean
for SocketProperties has the same issue.

Similar issues exist throughout the Tomcat MBeans. Looking at your config, am I
correct in thinking you are just interested in the ThreadPool MBeans?

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GUMP@vmgump-vm3]: Project tomcat-trunk-test-nio2 (in module tomcat-trunk) failed

2018-11-01 Thread Bill Barker
To whom it may engage...

This is an automated request, but not an unsolicited one. For 
more information please visit http://gump.apache.org/nagged.html, 
and/or contact the folk at gene...@gump.apache.org.

Project tomcat-trunk-test-nio2 has an issue affecting its community integration.
This issue affects 1 projects.
The current state of this project is 'Failed', with reason 'Build Failed'.
For reference only, the following projects are affected by this:
- tomcat-trunk-test-nio2 :  Tomcat 9.x, a web server implementing the Java 
Servlet 4.0,
...


Full details are available at:
http://vmgump-vm3.apache.org/tomcat-trunk/tomcat-trunk-test-nio2/index.html

That said, some information snippets are provided here.

The following annotations (debug/informational/warning/error messages) were 
provided:
 -DEBUG- Dependency on bnd exists, no need to add for property bndlib.jar.
 -INFO- Failed with reason build failed
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/logs-NIO2
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-NIO2/logs
 -WARNING- No directory 
[/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-NIO2/logs]



The following work was performed:
http://vmgump-vm3.apache.org/tomcat-trunk/tomcat-trunk-test-nio2/gump_work/build_tomcat-trunk_tomcat-trunk-test-nio2.html
Work Name: build_tomcat-trunk_tomcat-trunk-test-nio2 (Type: Build)
Work ended in a state of : Failed
Elapsed: 24 mins 5 secs
Command Line: /usr/lib/jvm/java-8-oracle/bin/java -Djava.awt.headless=true 
-Dbuild.sysclasspath=only -Dsun.zip.disableMemoryMapping=true 
org.apache.tools.ant.Main -Dgump.merge=/srv/gump/public/gump/work/merge.xml 
-Djunit.jar=/srv/gump/public/workspace/junit/target/junit-4.13-SNAPSHOT.jar 
-Djava.net.preferIPv4Stack=/srv/gump/public/workspace/tomcat-trunk/true 
-Dobjenesis.jar=/srv/gump/public/workspace/objenesis/main/target/objenesis-3.1-SNAPSHOT.jar
 -Dtest.reports=output/logs-NIO2 -Dexecute.test.nio2=true 
-Dexamples.sources.skip=true 
-Dbase.path=/srv/gump/public/workspace/tomcat-trunk/tomcat-build-libs 
-Djdt.jar=/srv/gump/packages/eclipse/plugins/R-4.7.3a-201803300640/ecj-4.7.3a.jar
 -Dbndlib.jar=/srv/gump/packages/bnd/bndlib-4.0.0/biz.aQute.bndlib-4.0.0.jar 
-Dcommons-daemon.jar=/srv/gump/public/workspace/apache-commons/daemon/target/commons-daemon-1.1.1-SNAPSHOT.jar
 
-Dtest.openssl.path=/srv/gump/public/workspace/openssl-master/dest-20181101/bin/openssl
 -Dtest.temp=output/test-tmp-NIO2
  -Dtest.accesslog=true -Dexecute.test.nio=false 
-Dbnd.jar=/srv/gump/packages/bnd/bnd-4.0.0/biz.aQute.bnd-4.0.0.jar 
-Dexecute.test.apr=false -Dtest.excludePerformance=true -Dtest.relaxTiming=true 
-Deasymock.jar=/srv/gump/public/workspace/easymock/core/target/easymock-4.1-SNAPSHOT.jar
 -Dhamcrest.jar=/srv/gump/packages/hamcrest/hamcrest-core-1.3.jar 
-Dcglib.jar=/srv/gump/packages/cglib/cglib-nodep-2.2.jar test 
[Working Directory: /srv/gump/public/workspace/tomcat-trunk]
CLASSPATH: 
/usr/lib/jvm/java-8-oracle/lib/tools.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/webapps/examples/WEB-INF/classes:/srv/gump/public/workspace/tomcat-trunk/output/testclasses:/srv/gump/public/workspace/ant/dist/lib/ant.jar:/srv/gump/public/workspace/ant/dist/lib/ant-launcher.jar:/srv/gump/public/workspace/ant/dist/lib/ant-jmf.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit4.jar:/srv/gump/public/workspace/ant/dist/lib/ant-swing.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-resolver.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-xalan2.jar:/srv/gump/public/workspace/xml-commons/java/build/resolver.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/bootstrap.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/tomcat-juli.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/annotations-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/servlet-api.ja
 
r:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jsp-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/el-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/websocket-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jaspic-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ant.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-storeconfig.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-coyote.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper-el.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-tribes.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ha.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-api.jar:/srv/gump/public/workspace/tomcat-trunk

svn commit: r1845519 - in /tomcat/trunk: java/org/apache/tomcat/util/net/ test/org/apache/catalina/mbeans/ webapps/docs/

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 23:03:08 2018
New Revision: 1845519

URL: http://svn.apache.org/viewvc?rev=1845519&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=62871
Improve MBeans for Endpoint instances (type ThreadPool in JMX) by using 
explicit declaration of attributes and operations rather than relying on 
introspection. Add a new MBean to expose the Socketproperties values.

Added:
tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml   (with 
props)
Modified:
tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java
tomcat/trunk/java/org/apache/tomcat/util/net/SocketProperties.java
tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java?rev=1845519&r1=1845518&r2=1845519&view=diff
==
--- tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java 
(original)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java Thu Nov  
1 23:03:08 2018
@@ -1085,6 +1085,11 @@ public abstract class AbstractEndpointhttp://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/SocketProperties.java?rev=1845519&r1=1845518&r2=1845519&view=diff
==
--- tomcat/trunk/java/org/apache/tomcat/util/net/SocketProperties.java 
(original)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/SocketProperties.java Thu Nov  
1 23:03:08 2018
@@ -24,6 +24,8 @@ import java.net.StandardSocketOptions;
 import java.nio.channels.AsynchronousServerSocketChannel;
 import java.nio.channels.AsynchronousSocketChannel;
 
+import javax.management.ObjectName;
+
 /**
  * Properties that can be set in the  element
  * in server.xml. All properties are prefixed with "socket."
@@ -173,6 +175,9 @@ public class SocketProperties {
  */
 protected int unlockTimeout = 250;
 
+private ObjectName oname = null;
+
+
 public void setProperties(Socket socket) throws SocketException{
 if (rxBufSize != null)
 socket.setReceiveBufferSize(rxBufSize.intValue());
@@ -421,5 +426,11 @@ public class SocketProperties {
 this.unlockTimeout = unlockTimeout;
 }
 
+void setObjectName(ObjectName oname) {
+this.oname = oname;
+}
 
+ObjectName getObjectName() {
+return oname;
+}
 }

Added: tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml?rev=1845519&view=auto
==
--- tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml (added)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml Thu Nov 
 1 23:03:08 2018
@@ -0,0 +1,696 @@
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+  
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+  
+
+
+
+
+
+  
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+  
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+  
+
+
+
+
+
+  
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+  
+
+
+
+  
+
+
+
+
+
+
+
+
+
+  
+
+
+
+
+
+  
+
+
+
+
+
+  
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+
+
+
+

Propchange: tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml

[Bug 62871] JMX: ThreadPool.socketProperties is not Serializable

2018-11-01 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=62871

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |FIXED
 Status|NEW |RESOLVED

--- Comment #2 from Mark Thomas  ---
The root cause is that the Endpoint (ThreadPool) MBeans are generated via
introspection so it is non-trivial to filter out unwanted attributes and/or
operations. If an mbeans-descriptors.xml was used, the filtering would be
trivial as the entries could just be removed.

There are a lot of attributes so manually generating the content for an
mbeans-descriptors.xml file would be time consuming. I've created a tool to
extract this data using the introspection code as a starting point:
https://github.com/markt-asf/tomcat-bugs/blob/master/src/java/org/apache/tomcat/MBeanDump.java

That allowed me to easily create an mbeans-descriptors.xml file for the
Endpoints which I then edited to remove the broken attributes and operations. I
also added a SWocketProperties Mbean although that looks like it would benefit
from some refactoring.

Fixed in:
- trunk for 9.0.13 onwards
- 8.5.x for 8.5.35 onwards

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1845520 - in /tomcat/tc8.5.x/trunk: ./ java/org/apache/tomcat/util/net/ test/org/apache/catalina/mbeans/ webapps/docs/

2018-11-01 Thread markt
Author: markt
Date: Thu Nov  1 23:10:06 2018
New Revision: 1845520

URL: http://svn.apache.org/viewvc?rev=1845520&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=62871
Improve MBeans for Endpoint instances (type ThreadPool in JMX) by using 
explicit declaration of attributes and operations rather than relying on 
introspection. Add a new MBean to expose the Socketproperties values.

Added:
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml
  - copied, changed from r1845519, 
tomcat/trunk/java/org/apache/tomcat/util/net/mbeans-descriptors.xml
Modified:
tomcat/tc8.5.x/trunk/   (props changed)
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/util/net/AbstractEndpoint.java
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/util/net/SocketProperties.java
tomcat/tc8.5.x/trunk/test/org/apache/catalina/mbeans/TestRegistration.java
tomcat/tc8.5.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Nov  1 23:10:06 2018
@@ -1,2 +1,2 @@
 /tomcat/tc8.0.x/trunk:1809644
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737903,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739492,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409
 
,1741501,1741677,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744149,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745083,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745473,1745535,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028,1747035,1747210,1747225,1747234,1747253,1747
 
404,1747506,1747536,1747924,1747980,1747993,1748001,1748253,1748452,1748547,1748629,1748676,1748715,1749287,1749296,1749328,1749373,1749465,1749506,1749508,1749665-1749666,1749763,1749865-1749866,1749898,1749978,1749980,1750011,1750015,1750056,1750480,1750617,1750634,1750692,1750697,1750700,1750703,1750707,1750714,1750718,1750723,1750774,1750899,1750975,1750995,1751061,1751097,1751173,1751438,1751447,1751463,1751702,1752212,1752737,1752745,1753078,1753080,1753358,1753363,1754111,1754140-1754141,1754281,1754310,1754445,1754467,1754494,1754496,1754528,1754532-1754533,1754613,1754714,1754874,1754941,1754944,1754950-1754951,1755005,1755007,1755009,1755132,1755180-1755181,1755185,1755190,1755204-1755206,1755208,1755214,1755224,1755227,1755230,1755629,1755646-1755647,1755650,1755653,1755675,1755680,1755683,1755693,1755717,1755731-1755737,1755812,1755828,1755884,1755890,1755918-1755919,1755942,1755958,1755960,1755970,1755993,1756013,1756019,1756039,1756056,1756083-1756114,1756175,1756288-1
 
756289,1756408-1756410,1756778,1756798,1756878,1756898,1756939,1757123-1757124,1757126,1757128,1757132-1757133,1757136,1757145,1757167-1757168,1757175,1757180,1757182,1757195,1757271,1757278,1757347,1757353-1757354,1757363,1757374,1757399,1757406,1757408,1757485,1757495,1757499,1757527,1757578,1757684,1757722,1757727,1757790,1757799,1757813,1757853,1757883,1757903,1757976,1757997,1758000,1758058,1758072-1758075,1758078-1758079,1758223,1758257,1758261,1758276,1758292,1758369,1758378-1758383,1758421,1758423,1758425-1758427,1758430,1758443,1758448,1758459,1758483,1758486-1758487,1758499,1758525,1758556,1758580,1758582,1758584,1758588,1758842,1759019,1759212,1759224,1759227,1759252,1759274,1759513-1759516,1759611,1759757,1759785-1759790,1760005,1760022,1760109-1760110,1760135,1760200-1760201,1760227,1760300,1760397,1

buildbot failure in on tomcat-trunk

2018-11-01 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-trunk while building 
. Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/3702

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1845519
Blamelist: markt

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org
--- tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl (original)
+++ tomcat/tc8.5.x/trunk/res/scripts/check-mime.pl Thu Nov  1 13:07:22 2018
@@ -23,31 +23,31 @@
 # The script uses two mime type lists to describe
 # the merging between httpd and Tomcat mime types.
 #
-# 1) %TOMCAT_ONLY: Additional extensions for Tomcat that do not exist in httpd
-# 2) %TOMCAT_KEEP: Mime type differences for common extensions where we stick 
to
+# - %TOMCAT_ONLY: Additional extensions for Tomcat that do not exist in httpd
+# - %TOMCAT_KEEP: Mime type differences for common extensions where we stick to
 #the Tomcat definition
 
 # The script checks consistency between Tomcat and httpd according
-# to the lists 1) and 2) and generates a new web.xml:
+# to the lists TOMCAT_ONLY and TOMCAT_KEEP and generates a new web.xml:
 #
 # A) Additional extensions in Tomcat which are not part of 1)
 #are logged. They will be removed in the generated new web.xml.
 #If you want to keep them, add them to the list 1) and run the
 #script again. If you want to remove them, commit the generated
 #new web.xml.
 # B) Mime type differences for the same extension between httpd
 #and Tomcat that are not part of the list 2) are logged.
 #They will be overwritten wit the httpd definition in the generated
 #new web.xml. If you want to keep their Tomcat definition, add them
 #to the list 1) and run the script again. If you want to use the
 #definitions from httpd, commit the generated new web.xml.
 # C) Additional extensions in httpd are logged. The script outputs a
 #merged web.xml, which already includes all those additional
-#extensions. If you want to keep them, update web.xml with the
-#generated new web.xml.
+#extensions. If you want to keep them, commit the generated
+#new web.xml.
 # D) If the extensions are not sorted alphabetically, a message is logged.
-#The generated web.xml will be always be sorted alphabetically.
-#If you want to fix the sort order, update web.xml with the generated
+#The generated web.xml will always be sorted alphabetically.
+#If you want to keep the alphabetical sort order, commit the generated
 #new web.xml.
 
 use strict;
@@ -77,13 +77,10 @@ my %TOMCAT_ONLY = qw(
 body text/html
 dib image/bmp
 dv video/x-dv
-flac audio/flac
 gz application/x-gzip
-hqx application/mac-binhex40
 htc text/x-component
 jsf text/plain
 jspf text/plain
-m4a audio/mp4
 m4b audio/mp4
 m4r audio/mp4
 mp1 audio/mpeg
@@ -108,6 +105,7 @@ my %TOMCAT_KEEP = qw(
 cdf application/x-cdf
 class application/java
 exe application/octet-stream
+flac audio/flac
 m4v video/mp4
 mif application/x-mif
 pct image/pict
@@ -181,6 +179,18 @@ if ($opt_m eq '' || $opt_i eq '' || $opt
 # Switch locale for alphabetical ordering
 setlocale(LC_COLLATE, $LOCALE);
 
+# Check whether TOMCAT_ONLY and TOMCAT_KEEP are disjoint
+for $extension (sort keys %TOMCAT_ONLY) {
+if (exists($TOMCAT_KEEP{$extension})) {
+push(@extensions, ($extension));
+}
+}
+if (@extensions > 0) {
+print STDERR "FATAL Lists TOMCAT_ONLY and TOMCAT_KEEP must be disjoint.\n";
+print STDERR "FATAL Common entries are: " . join(', ', @extensions) . " - 
Aborting!\n";
+exit 6;
+}
+
 # Read and parse httpd mime.types, build up hash extension->mime-type
 open($mimetypes_fh, '<', $opt_m) or die "Could not open file '$opt_m' for read 
- Aborting!";
 while (<$mimetypes_fh>) {
@@ -321,6 +331,54 @@ while (<$webxml_fh>) {
 close($webxml_fh);
 
 
+# Look for extensions in TOMCAT_ONLY.
+# Abort if it already exists in mime.types.
+# Warn if they are no longer existing in web.xml.
+for $extension (s

svn commit: r1845474 - /tomcat/tc8.5.x/trunk/

2018-11-01 Thread rjung
Author: rjung
Date: Thu Nov  1 13:09:31 2018
New Revision: 1845474

URL: http://svn.apache.org/viewvc?rev=1845474&view=rev
Log:
Forgot to commit mergeinfo.

Modified:
tomcat/tc8.5.x/trunk/   (props changed)

Propchange: tomcat/tc8.5.x/trunk/
--
@@ -23,31 +23,31 @@
 #
-# A) Additional extensions in Tomcat which are not part of 1)
+# A) Additional extensions in Tomcat which are not part of TOMCAT_ONLY
 #are logged. They will be removed in the generated new web.xml.
@@ -23,31 +23,31 @@
 #are logged. They will be removed in the generated new web.xml.
-#If you want to keep them, add them to the list 1) and run the
+#If you want to keep them, add them to TOMCAT_ONLY and run the
 #script again. If you want to remove them, commit the generated
 #new web.xml.
@@ -23,31 +23,31 @@
 #new web.xml.
 # B) Mime type differences for the same extension between httpd
-#and Tomcat that are not part of the list 2) are logged.
+#and Tomcat that are not part of TOMCAT_KEEP are logged.
 #They will be overwritten wit the httpd definition in the generated
 #new web.xml. If you want to keep their Tomcat definition, add them
@@ -23,31 +23,31 @@
 #They will be overwritten wit the httpd definition in the generated
 #new web.xml. If you want to keep their Tomcat definition, add them
-#to the list 1) and run the script again. If you want to use the
+#to TOMCAT_KEEP and run the script again. If you want to use the
 #definitions from httpd, commit the generated new web.xml.
 # C) Additional extensions in httpd are logged. The script outputs a